@@ -29,6 +29,11 @@ class SensiboClient(object):
         self._session = session if session else ClientSession()
         self.timeout = timeout
 
+    async def async_get_me(self) -> dict[str, Any]:
+        """Return info about me."""
+        params = {"apiKey": self.api_key}
+        return await self._get(APIV1 + "/users/me", params)
+
     async def async_get_devices(self, fields: str = "*") -> dict[str, Any]:
         """Get all devices.
 
@@ -200,7 +205,7 @@ class SensiboClient(object):
     async def _get(self, path: str, params: dict[str, Any]) -> dict[str, Any]:
         """Make GET api call to Sensibo api."""
         async with self._session.get(path, params=params, timeout=self.timeout) as resp:
-            if resp.status == 401:
+            if resp.status in [401, 403]:
                 raise AuthenticationError("Invalid API key")
             if resp.status != 200:
                 error = await resp.text()
@@ -218,7 +223,7 @@ class SensiboClient(object):
         async with self._session.put(
             path, params=params, data=json.dumps(data), timeout=self.timeout
         ) as resp:
-            if resp.status == 401:
+            if resp.status in [401, 403]:
                 raise AuthenticationError("Invalid API key")
             if resp.status != 200:
                 error = await resp.text()
@@ -236,7 +241,7 @@ class SensiboClient(object):
         async with self._session.post(
             path, params=params, data=json.dumps(data), timeout=self.timeout
         ) as resp:
-            if resp.status == 401:
+            if resp.status in [401, 403]:
                 raise AuthenticationError("Invalid API key")
             if resp.status != 200:
                 error = await resp.text()
@@ -254,7 +259,7 @@ class SensiboClient(object):
         async with self._session.patch(
             path, params=params, data=json.dumps(data), timeout=self.timeout
         ) as resp:
-            if resp.status == 401:
+            if resp.status in [401, 403]:
                 raise AuthenticationError("Invalid API key")
             if resp.status != 200:
                 error = await resp.text()
@@ -270,7 +275,7 @@ class SensiboClient(object):
         async with self._session.delete(
             path, params=params, timeout=self.timeout
         ) as resp:
-            if resp.status == 401:
+            if resp.status in [401, 403]:
                 raise AuthenticationError("Invalid API key")
             if resp.status != 200:
                 error = await resp.text()
